Function defmt_ringbuf::init
source · pub unsafe fn init<const SIZE: usize>(
ring_buffer: &'static mut RingBuffer<SIZE>,
log_available: fn()
)Expand description
Initializes logging to a ring buffer.
ring_buffer specifies the location of the log buffer.
It is not cleared if it contains vailid data from the previous boot.
log_available is called when new log messages are available.
This must be called exactly once. Log messages received before initiailization are discarded.